==> haskell-hspec-expectations-0.8.2-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-GGGXL2nWs981V3xvQdYYx0
key:                  hspec-expectations-0.8.2-GGGXL2nWs981V3xvQdYYx0
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  ef40a4359305fdb185fb8da2abb5de69
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hspec-expectations-0.8.2
hs-libraries:         HShspec-expectations-0.8.2-GGGXL2nWs981V3xvQdYYx0
depends:
    HUnit-1.6.2.0-2lDDmQCEetY9OrwZ2lDZMS base-4.15.0.0
    call-stack-0.4.0-8Okwb0cowpe8mB1pBLnCB

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-0.8.2-271-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-16R3L7h7s7K10qPKYuZxJb
key:                  hspec-expectations-0.8.2-16R3L7h7s7K10qPKYuZxJb
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  b872dabd392d5e4fab77b8118ab15a09
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations
hs-libraries:         HShspec-expectations-0.8.2-16R3L7h7s7K10qPKYuZxJb
depends:
    HUnit-1.6.2.0-2gufKd42xUzCpoVbpNtVHq base-4.15.1.0
    call-stack-0.4.0-GzzQb9Lrk0g4HpVkjTQ3aR

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
